diff --git a/README.md b/README.md
index f11a6a4..fde651a 100644
--- a/README.md
+++ b/README.md
@@ -1,7 +1,7 @@
Java Code Styles
================
-IntelliJ IDEA code style settings for Square's Java and Android projects.
+IntelliJ IDEA code style settings for Clovify's Java and Android projects.
Installation
diff --git a/configs/Clovify.xml b/configs/Clovify.xml
new file mode 100644
index 0000000..facd87c
--- /dev/null
+++ b/configs/Clovify.xml
@@ -0,0 +1,217 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/configs/Square.xml b/configs/Square.xml
deleted file mode 100644
index bf3cec9..0000000
--- a/configs/Square.xml
+++ /dev/null
@@ -1,248 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/configs/SquareAndroid.xml b/configs/SquareAndroid.xml
deleted file mode 100644
index 47dff00..0000000
--- a/configs/SquareAndroid.xml
+++ /dev/null
@@ -1,219 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
\ No newline at end of file
diff --git a/install.sh b/install.sh
index a461c00..bfa8751 100755
--- a/install.sh
+++ b/install.sh
@@ -1,18 +1,23 @@
#!/bin/bash
-# Installs Square's IntelliJ configs into your user configs.
+# Installs Clovify's IntelliJ configs into your user configs.
-echo "Installing Square code style configs..."
+echo "Installing Clovify code style configs..."
-for i in $HOME/Library/Preferences/IntelliJIdea*/codestyles \
- $HOME/Library/Preferences/IdeaIC*/codestyles \
- $HOME/Library/Preferences/AndroidStudio*/codestyles \
- $HOME/.IntelliJIdea*/config/codestyles \
- $HOME/.IdeaIC*/config/codestyles \
- $HOME/.AndroidStudio*/config/codestyles
+CONFIGS="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )/configs"
+
+for i in $HOME/Library/Preferences/IntelliJIdea* \
+ $HOME/Library/Preferences/IdeaIC* \
+ $HOME/Library/Preferences/AndroidStudio* \
+ $HOME/.IntelliJIdea*/config \
+ $HOME/.IdeaIC*/config \
+ $HOME/.AndroidStudio*/config
do
- cp -frv $( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )/configs/* $i 2> /dev/null
+ if [ -d $i ]; then
+ mkdir -p $i/codestyles
+ cp -frv "$CONFIGS"/* $i/codestyles
+ fi
done
echo "Done."
echo ""
-echo "Restart IntelliJ and/or AndroidStudio, go to preferences, and apply 'Square' or 'SquareAndroid'."
+echo "Restart IntelliJ and/or AndroidStudio, go to preferences, and apply 'Clovify'."